ROTS(data, groups, B, K, paired = FALSE, seed = NULL, a1 = NULL, a2 = NULL, log = TRUE, progress = FALSE)ROTS returns an object of class ROTS, which is a list
containing the following componentsprint prints the optimized parameters a1 and a2, the optimized
top list size and the corresponding reproducibility values.summary summarizes the results of a ROTS analysis. If
fdr and num.genes are not specified, then the optimized
parameters a1 and a2, the optimized top list size and the
corresponding reproducibility values are shown. If fdr or
num.genes is specified, then also the gene-specific information
is shown for the genes at the specified FDR-level or top list size,
respectively.
impute.
If the parameter values a1 and a2 are set by the user, then no
optimization is performed but the statistic and FDR-values are
calculated for the given parameters. The false discovery rate (FDR)
for the optimized test statistic is calculated by permuting the sample
labels. The results for all the genes can be obtained by setting the
FDR cutoff to 1.
affySpikeIn ## ROTS-statistic for the Affymetrix spike-in data.
rots.out <- ROTS(data = affySpikeIn, groups = c(rep(0,5), rep(1,5)),
B = 100, K = 500 , seed = 1234)
## Summary of the ROTS results.
rots.summary <- summary(rots.out, fdr = 0.05)
Run the code above in your browser using DataLab